@@ -18,7 +18,7 @@ class K8SDeploymentAdapter(DeploymentAdapter):
         return str(stdout) if stdout else None
 
     def validate_profile_data(self) -> None:
-        if self.profile_data.k8s_namespace is None:
+        if self.profile_data.config["k8s"]["namespace"] is None:
             raise click.ClickException("Missing K8S Namespace attribute or profile")
         if self.profile_data.docker_registry_url is None:
             raise click.ClickException(
@@ -27,9 +27,6 @@ class K8SDeploymentAdapter(DeploymentAdapter):
         if self.docker_image_tag is None or len(self.docker_image_tag) == 0:
             raise click.ClickException("Missing Docker image tag attribute")
 
-    def get_template_name(self) -> str:
-        return "k8s_flink_deployment.yml"
-
     @staticmethod
     def _kubectl_apply(deployment_yml: str) -> Tuple[bytes, bytes]:
         cmd = subprocess.Popen(
