@@ -1,3 +1,6 @@
+import os
+from pathlib import Path
+
 import hiyapyco
 
 from streamingcli.project.yaml_merger import YamlMerger
@@ -7,12 +10,12 @@ class TestYamlMerger:
     """Test merging two YAML files"""
 
     def test_merge_two_yaml_files(self):
+        os.chdir(Path(__file__).parent)
+
         merged = YamlMerger.merge_two_yaml(
-            "tests/streamingcli/project/yaml/input_1.yml",
-            "tests/streamingcli/project/yaml/input_2.yml",
-        )
-        expected = hiyapyco.dump(
-            hiyapyco.load("tests/streamingcli/project/yaml/expected.yml")
+            "yaml/input_1.yml",
+            "yaml/input_2.yml",
         )
+        expected = hiyapyco.dump(hiyapyco.load("yaml/expected.yml"))
 
         assert merged == expected
